@@ -85,7 +85,7 @@
 		$err
 	);
 
-	our $VERSION = "2023.111.1";
+	our $VERSION = "2023.199.1";
 
 	our @EXPORT_OK = @EXPORT;
 
@@ -643,6 +643,7 @@ sub _Select()
 	}
 	my @fields_work;
 	my %fields_distinct;
+	my %fields_aliases;
 	if (defined($argv->{fields}))
         {
 		if (ref($argv->{fields}) ne "ARRAY")
@@ -654,6 +655,13 @@ sub _Select()
 		{
 			my $field = $argv->{fields}[$ix];
 			my $distinct;
+			my $alias;
+			if (ref($field) eq "HASH")
+			{
+				$alias = $field;
+				($fields_aliases{$alias}{f},$fields_aliases{$alias}{a}) = each(%{$field});
+				$field = $fields_aliases{$alias}{f};
+			}
 			if ($field =~ /^distinct$/i)
 			{
 				$field = $argv->{fields}[++$ix];
@@ -677,7 +685,7 @@ sub _Select()
 					}
 				}
 			}
-			push(@fields_work,$field);
+			push(@fields_work,$alias || $field);
 			$fields_distinct{$field} = 1 if ($distinct);
 		}
 	}
@@ -745,11 +753,20 @@ sub _Select()
 	{
 		foreach my $field(@fields_work)
 		{
+			my $alias;
 			my $distinct = ($fields_distinct{$field}) ? "DISTINCT " : "";
-			## escape?
+			## field is hash?
+			if (defined($fields_aliases{$field}))
+			{
+				$alias = $fields_aliases{$field}{a};
+				$field = $fields_aliases{$field}{f};
+			}
+			## is escape?
 			if ($field =~ /^\\(.*)/)
 			{
-				push(@fields,$distinct.$1);
+				($alias) ?
+					push(@fields,$distinct.$1." ".$alias) :
+					push(@fields,$distinct.$1);
 				next;
 			}
 			## have function?
@@ -778,6 +795,8 @@ sub _Select()
 				my $table = $1;
 				my $field = $2;
 				my $realn = $self->getAliasCols($table,$field);
+				($alias) ?
+					push(@fields,$distinct.$field_a.$table.".".$realn.$field_b." ".$alias) :
 				($field ne $realn) ?
 					push(@fields,$distinct.$field_a.$table.".".$realn.$field_b." ".$table."_".$field) :
 					push(@fields,$distinct.$field_a.$table.".".$realn.$field_b);
@@ -787,11 +806,18 @@ sub _Select()
 				if (@tables_work == 1)
 				{
 					my $realn = $self->getAliasCols($table,$field);
+					($alias) ?
+						push(@fields,$distinct.$field_a.$realn.$field_b." ".$alias) :
 					($field ne $realn) ?
 						push(@fields,$distinct.$field_a.$realn.$field_b." ".$field) :
 						push(@fields,$distinct.$field_a.$field.$field_b);
 				}
-				else { push(@fields,$distinct.$field); }
+				else
+				{
+					($alias) ?
+						push(@fields,$distinct.$field." ".$alias):
+						push(@fields,$distinct.$field);
+			     	}
 			}
 		}
 	}
